#[repr(transparent)]pub struct SystCvr(pub u32);Expand description
SysTick Current Value Register
Tuple Fields
0: u32Implementations
Sourceimpl SystCvr
impl SystCvr
Sourcepub const fn current(&self) -> u32
pub const fn current(&self) -> u32
Reads current counter value at the time the register is accessed. Any write to the register clears the register to 0.
Sourcepub const fn set_current(&mut self, val: u32)
pub const fn set_current(&mut self, val: u32)
Reads current counter value at the time the register is accessed. Any write to the register clears the register to 0.